<?php

namespace Sit\Hotel\Policies;

use Litepie\User\Contracts\UserPolicy;
use Sit\Hotel\Models\HotelsCategory;

class HotelsCategoryPolicy
{

    /**
     * Determine if the given user can view the hotels_category.
     *
     * @param UserPolicy $user
     * @param HotelsCategory $hotels_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, HotelsCategory $hotels_category)
    {
        if ($user->canDo('hotel.hotels_category.view') && $user->isAdmin()) {
            return true;
        }

        return $hotels_category->user_id == user_id() && $hotels_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a hotels_category.
     *
     * @param UserPolicy $user
     * @param HotelsCategory $hotels_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('hotel.hotels_category.create');
    }

    /**
     * Determine if the given user can update the given hotels_category.
     *
     * @param UserPolicy $user
     * @param HotelsCategory $hotels_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, HotelsCategory $hotels_category)
    {
        if ($user->canDo('hotel.hotels_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $hotels_category->user_id == user_id() && $hotels_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given hotels_category.
     *
     * @param UserPolicy $user
     * @param HotelsCategory $hotels_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, HotelsCategory $hotels_category)
    {
        return $hotels_category->user_id == user_id() && $hotels_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given hotels_category.
     *
     * @param UserPolicy $user
     * @param HotelsCategory $hotels_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, HotelsCategory $hotels_category)
    {
        if ($user->canDo('hotel.hotels_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given hotels_category.
     *
     * @param UserPolicy $user
     * @param HotelsCategory $hotels_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, HotelsCategory $hotels_category)
    {
        if ($user->canDo('hotel.hotels_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
