<?php

namespace Sit\Hotel\Providers;

use Illuminate\Support\ServiceProvider;

class HotelServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'hotel');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'hotel');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerHotel();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerHotel()
    {
        $this->app->bind('hotel', function($app) {
            return new Hotel($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Hotel', 'Lavalite\Hotel\Facades\Hotel');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('sit.hotel', function ($app) {
            return $this->app->make('Sit\Hotel\Hotel');
        });

        // Bind Hotel to repository
        $this->app->bind(
            'Sit\Hotel\Interfaces\HotelRepositoryInterface',
            \Sit\Hotel\Repositories\Eloquent\HotelRepository::class
        );
        // Bind HotelsCategory to repository
        $this->app->bind(
            'Sit\Hotel\Interfaces\HotelsCategoryRepositoryInterface',
            \Sit\Hotel\Repositories\Eloquent\HotelsCategoryRepository::class
        );

        $this->app->register(\Sit\Hotel\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Sit\Hotel\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and hotel's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/hotel.php', 'hotel'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeHotel::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['sit.hotel'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('sit/hotel.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/hotel')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/hotel')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
