<?php

namespace Sit\Hotel\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Sit\Hotel\Models\Hotel;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Sit\Hotel\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/hotel/hotel/*')) {
            Route::bind('hotel', function ($hotel) {
                $hotelrepo = $this->app->make('Sit\Hotel\Interfaces\HotelRepositoryInterface');
                return $hotelrepo->findorNew($hotel);
            });
        }

        if (Request::is('*/hotel/hotels_category/*')) {
            Route::bind('hotels_category', function ($hotels_category) {
                $hotels_categoryrepo = $this->app->make('Sit\Hotel\Interfaces\HotelsCategoryRepositoryInterface');
                return $hotels_categoryrepo->findorNew($hotels_category);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
